Index: ash/shell_delegate.h |
diff --git a/ash/shell_delegate.h b/ash/shell_delegate.h |
index 922462900a1c569a59da7d14f451e670be510f80..e3c6f5f98e6d5bfc1154370c350aaabd5e53a0cc 100644 |
--- a/ash/shell_delegate.h |
+++ b/ash/shell_delegate.h |
@@ -15,7 +15,7 @@ |
class GURL; |
namespace app_list { |
-class AppListShower; |
+class AppListPresenter; |
class AppListViewDelegate; |
} |
@@ -113,8 +113,8 @@ class ASH_EXPORT ShellDelegate { |
// Opens the |url| in a new browser tab. |
virtual void OpenUrl(const GURL& url) = 0; |
- // Get the AppListShower. Ownership stays with Chrome. |
- virtual app_list::AppListShower* GetAppListShower() = 0; |
+ // Get the AppListPresenter. Ownership stays with Chrome. |
+ virtual app_list::AppListPresenter* GetAppListPresenter() = 0; |
// Creates a new ShelfDelegate. Shell takes ownership of the returned |
// value. |